/**
 * EasyBeans
 * Copyright (C) 2007 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: StartMojo.java 1942 2007-10-14 17:57:26Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.osgi.plugins.launcher;

import org.apache.maven.plugin.MojoExecutionException;
import org.ow2.easybeans.osgi.plugins.launcher.api.LauncherException;


/**
 * Stop an OSGi framework.
 * @goal start
 * @phase pre-integration-test
 * @author Florent BENOIT
 */
public class StartMojo extends AbsMojo {

    /**
     * Waiting value after the start.
     * @parameter
     * @optional
     */
    private long waitAfterStart = 0;

    /**
     * List of bundles to start in the given order (by their symbolic name).
     * @parameter
     * @optional
     */
    private String[] startOrderBundles = null;

    /**
     * List of bundles to start after a given delay.
     * @parameter
     * @optional
     */
    private DelayedBundlePattern[] delayedBundles = null;

    /**
     * Start the OSGi framework.
     * @throws MojoExecutionException if there is a failure.
     */
    protected void doExecute() throws MojoExecutionException {

        // Launch the framework with the given configuration
        try {
            getLauncher().start();
        } catch (LauncherException e) {
            throw new MojoExecutionException("Cannot launch the framework");
        }
    }

    /**
     * Gets the configuration used by the launcher by updating it with specific values.
     * @return a configuration object
     * @throws MojoExecutionException if the configuration can't be built.
     */
    @Override
    protected Configuration getConfiguration() throws MojoExecutionException {
        // Get configuration object.
        Configuration configuration = super.getConfiguration();

        // Add properties
        configuration.setWaitAfterStart(waitAfterStart);
        configuration.setStartOrderBundles(startOrderBundles);
        configuration.setDelayedBundles(delayedBundles);

        return configuration;

    }


}
